import numpy as np
import matplotlib.pyplot as plt


#change defaults for plotting
#set line width
plt.rcParams['lines.linewidth'] = 4
#set font size for titles 
plt.rcParams['axes.titlesize'] = 20
#set font size for labels on axes
plt.rcParams['axes.labelsize'] = 20
#set size of numbers on x-axis
plt.rcParams['xtick.labelsize'] = 16
#set size of numbers on y-axis
plt.rcParams['ytick.labelsize'] = 16
#set size of ticks on x-axis
plt.rcParams['xtick.major.size'] = 7
#set size of ticks on y-axis
plt.rcParams['ytick.major.size'] = 7
#set size of markers, e.g., circles representing points
#set numpoints for legend
plt.rcParams['legend.numpoints'] = 1
#set parameters for saving figures
plt.rcParams['savefig.dpi'] = 1000
plt.rcParams['savefig.bbox'] = 'tight'
plt.rcParams['savefig.pad_inches'] = 0

mySamples = []
myLinear = []
myQuadratic = []
myCubic = []
myExponential = []

for i in range(0, 30):
    mySamples.append(i)
    myLinear.append(i)
    myQuadratic.append(i**2)
    myCubic.append(i**3)
    myExponential.append(1.5**i)

##### Plotting one line
plt.plot(mySamples, myLinear)

###### Plotting many lines
#plt.plot(mySamples, myLinear)
#plt.plot(mySamples, myQuadratic)
#plt.plot(mySamples, myCubic)
#plt.plot(mySamples, myExponential)

###### Plotting two lines on one plot
#plt.figure('expo')
#plt.plot(mySamples, myExponential)
#plt.figure('lin')
#plt.plot(mySamples, myLinear)
#plt.figure('quad')
#plt.plot(mySamples, myQuadratic)
#plt.figure('cube')
#plt.plot(mySamples, myCubic)
#newExpo = []
#for i in range(30):
#    newExpo.append(1.6**i)
#plt.figure('expo')
#plt.plot(mySamples, newExpo)

###### Plotting temperatures and changing xaxis
#months = range(1, 13, 1)
#temps = [28,32,39,48,59,68,75,73,66,54,45,34]
#plt.plot(months, temps)
### Add axes, labels, and a title
#plt.title('Ave. Temperature in Boston')
#plt.xlabel('Month')
#plt.ylabel(('Degrees F'))
### Start axis at 1 to 12
#plt.xlim(1, 12)
### Change x axes labels
#plt.xticks((1,2,3,4,5,6,7,8,9,10,11,12))
### Change x axes labels to custom labels
#plt.xticks((1,2,3,4,5,6,7,8,9,10,11,12),
#           ('Jan','Feb','Mar','Apr','May','Jun','Jul','Aug','Sep','Oct','Nov','Dec'))

###### Plotting multiple lines with labels
#months = range(1, 13, 1)
#boston = [28,32,39,48,59,68,75,73,66,54,45,34]
#plt.plot(months, boston, label = 'Boston')
#phoenix = [54,57,61,68,77,86,91,90,84,73,61,54]
#plt.plot(months, phoenix, label = 'Phoenix')
#plt.legend(loc = 'best') # position it automatically
## Add labels and title
#plt.title('Ave. Temperatures')
#plt.xlabel('Month')
#plt.ylabel(('Degrees F'))
## Change x axis labels to custom labels
#plt.xticks((1,2,3,4,5,6,7,8,9,10,11,12),
#           ('Jan','Feb','Mar','Apr','May','Jun','Jul','Aug','Sep','Oct','Nov','Dec'))

###### Plotting multiple lines and changing their line style
#months = range(1, 13, 1)           
#boston = [28,32,39,48,59,68,75,73,66,54,45,34]
#plt.plot(months, boston, 'b-', label = 'Boston')
#phoenix = [54,57,61,68,77,86,91,90,84,73,61,54]
#plt.plot(months, phoenix, 'r--', label = 'Phoenix')
#msp = [16,19,34,48,59,70,75,73,64,60,37,21]
#plt.plot(months, msp, 'g.-.', label = 'Minneapolis')
#plt.legend(loc = 'best')
#
#plt.title('Ave. Temperatures')
#plt.xlabel('Month')
#plt.ylabel(('Degrees F'))
#
#plt.xticks((1,2,3,4,5,6,7,8,9,10,11,12),
#           ('Jan','Feb','Mar','Apr','May','Jun',\
#           'Jul','Aug','Sep','Oct','Nov','Dec'))


###### Read file data and plot it
def getUSPop(fileName):
    inFile = open(fileName, 'r')
    dates, pops = [], []
    for l in inFile:
        line = ''
        for c in l:
            if c in '0123456789 ':
                line += c
        line = line.split(' ')
        dates.append(int(line[0]))
        pops.append(int(line[1][:-1]))
    return dates, pops

#dates, pops = getUSPop('lect11_USPopulation.txt')
#plt.plot(dates, pops)
#plt.title('Population in What Is Now U.S\n' +\
#          '(Native Am. Excluded Before 1860)')
#plt.xlabel('Year')
#plt.ylabel('Population')
#### Change the scale to semilog
#plt.semilogy()   

###### Read file data from many countries and plot it
def getCountryPops(fileName):
    inFile = open(fileName, 'r')
    pops = []
    for l in inFile:
        line = l.split('\t')
        l = line[2]
        pop = ''
        for c in l:
            if c in '0123456789':
                pop += c
        pops.append(int(pop))
    return pops

#pops = getCountryPops('lect11_countryPops.txt')
#plt.plot(pops)
#plt.title('Population Size of Countries July 2017')
#plt.ylabel('Population')
#plt.xlabel('Country Rank Based on Size')
#plt.semilogy()

pops = getCountryPops('lect11_countryPops.txt')
firstDigits = []
for p in pops:
    firstDigits.append(int(str(p)[0]))
#plt.plot(firstDigits)
## Plot the histogram to show Benford's law
#plt.hist(firstDigits, bins = 9)


###### Plotting temperatures and changing xaxis
def retire(savingPerMo, rate, durations):
    savings = [0]
    base = [0]
    mRate = rate/12
    for i in range(durations):
        base += [i]
        savings += [savings[-1]*(1 + mRate) + savingPerMo]
    return base, savings
    
def varySavingRate(monthlies, rate, terms):
    plt.figure('retireMonth')
    for monthly in monthlies:
        xvals, yvals = retire(monthly, rate, terms)
        plt.plot(xvals, yvals, 
                 label = '$'+str(monthly)+'/mo.')
    plt.legend(loc = 'upper left')
    plt.xlabel('Months to Retirement')
    plt.ylabel('$ at Retirement')
    plt.title('Retirment Nestegg ('+str(round(rate*100, 2))+'% Ann. Int.)')

#varySavingRate([500, 600, 700, 800, 900, 1000], .03, 40*12)

def varyInterestRate(month, rates, terms):
    plt.figure('retireRate')
    plt.clf()
    for rate in rates:
        xvals, yvals = retire(month, rate, terms)
        plt.plot(xvals, yvals,                  
                 label = str(round(rate*100, 2))+'% ann. rate')
    plt.legend(loc = 'upper left')
    plt.xlabel('Months to Retirement')
    plt.ylabel('$ at Retirement')
    plt.title('Retirment Nestegg ($'+str(month)+'/mo. Savings)')

#varyInterestRate(800,[.03, .05, .07], 40*12)
